@@ -20,7 +20,7 @@ def get_shell_extension():
     return extension
 
 def evaluate_statuscode(statusCode):
-    diagnostics.StreamLogger log
+    log = diagnostics.StreamLogger()
     if platform.system().lower() == "windows":
         log.debug("Status Code:" + str(statusCode))
         if statusCode != 0:
